import javax.jms.*;
import javax.naming.*;
import java.rmi.RemoteException;

public class MsgListener implements javax.jms.MessageListener
{
    protected QueueConnectionFactory	connFactory = null;
    protected QueueConnection			queueConn = null;
    protected QueueSession			queueSession = null;
    protected Queue				queue = null;
    protected QueueReceiver			queueReceiver = null;
    public boolean finish = false;

    public void init() throws NamingException, JMSException, RemoteException
    {
        // get the initial context
        InitialContext ctx = new InitialContext();

        // lookup the queue object
        queue = (Queue) ctx.lookup("queue/queue0");

        // lookup the queue connection factory
        connFactory = (QueueConnectionFactory) ctx.lookup("queue/connectionFactory");

        // create a queue connection
        queueConn = connFactory.createQueueConnection();

        // create a queue session
        queueSession = queueConn.createQueueSession(false, Session.DUPS_OK_ACKNOWLEDGE);

        // create a queue receiver
        queueReceiver = queueSession.createReceiver(queue);

        // set the message listener
        queueReceiver.setMessageListener (this);

        // start the connection
        queueConn.start();

        System.out.println("JMS MsgListener started.");
    }
    public void close () throws JMSException
    {
        queueReceiver.close();
        queueSession.close();
        queueConn.close();
        System.out.println("JMS MsgListener stopped.");
    }
    public void onMessage (Message msg)
    {
        String text = "";
        System.out.println("onMessage() called.");
        try
        {
            if(msg instanceof ObjectMessage) {
            	ObjectMessage objmsg = (ObjectMessage)msg;
            	System.out.println("Received object: " + objmsg.getObject() );
            }
            else if(msg instanceof TextMessage) {
              	TextMessage textmsg = (TextMessage) msg;
                  text = textmsg.getText();
                  if (text == null) text = "";
                  if (text.equalsIgnoreCase("finish")) {
                      synchronized(this) {
                          System.out.println("***Received finish indicator in text***");
                          finish = true;
                      }
                  }
                  else System.out.println("Received text: " + textmsg.getText() );
		}
		else System.out.println("message type not supported");
        }
        catch (JMSException e)
        {
            e.printStackTrace ();
        }
        synchronized(this) {
            this.notifyAll();
        }
    }
}