package selector;

import javax.jms.Queue;

import javax.naming.Context;
import javax.naming.InitialContext;

import javax.jms.Queue;
import javax.jms.Session;
import javax.jms.Message;
import javax.jms.TextMessage;
import javax.jms.ObjectMessage;
import javax.jms.QueueSender;
import javax.jms.QueueSession;
import javax.jms.QueueReceiver;
import javax.jms.QueueConnection;
import javax.jms.QueueConnectionFactory;

public class Receiver
{
    public static void main(String[] args) throws Exception
    {
        // get the initial context
        InitialContext ctx = new InitialContext();

        // lookup the queue object
        Queue queue = (Queue) ctx.lookup("queue/queue0");

        // lookup the queue connection factory
        QueueConnectionFactory connFactory = (QueueConnectionFactory) ctx.
            lookup("queue/connectionFactory");

        // create a queue connection
        QueueConnection queueConn = connFactory.createQueueConnection();

        // create a queue session
        QueueSession queueSession = queueConn.createQueueSession(false,
            Session.DUPS_OK_ACKNOWLEDGE);

        // create a queue receiver for the filtered (interesting) messages
        QueueReceiver filteredQueueReceiver = 
		queueSession.createReceiver(queue,"Interesting=true");

        // create a queue receiver for all types of messages
        QueueReceiver queueReceiver = queueSession.createReceiver(queue);

        // start the connection
        queueConn.start();

        // get the filtered messages first...
        System.out.println("===============================");
        System.out.println("Looking for interesting messages first...");
        System.out.println("===============================");
        receiveMsgs(filteredQueueReceiver);

        // get the all other messages next...
        System.out.println("===============================");
        System.out.println("Looking for all remaining messages...");
        System.out.println("===============================");
        receiveMsgs(queueReceiver);

        // close the queue connection
        queueConn.close();
    }
    private static void receiveMsgs(QueueReceiver qr) throws Exception
    {
        while (true) {
            Message message = qr.receive(1000);	// timeout every second
            if (message != null) {
                String marketStatus = message.getStringProperty("MarketStatus");
                if (marketStatus == null) marketStatus = "";
                if (marketStatus.equalsIgnoreCase("closed")) {
                    System.out.println("Received Market Closed message, closing up shop.");
                    break;
                }
                if (message instanceof TextMessage) {
                    System.out.println("Received text message: "+((TextMessage) message).getText()); }
                else if (message instanceof ObjectMessage) {
                    System.out.println("Received object message: "+((ObjectMessage) message).getObject()); }
                else {
                    System.out.println("Ignored message type: "+message.getClass().getName()); }
            }
            else break;	// stop receive if we do not get a message
        }
    }
}
